#
# spec file for package python-msm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-msm
Version:        0.8.5
Release:        3.1
Summary:        Mycroft Skills Manager
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/MycroftAI/mycroft-skills-manager
Source:         https://github.com/MycroftAI/mycroft-skills-manager/archive/v%{version}.tar.gz
Patch1:         do-not-run-pip-or-requirements-script.patch
Patch2:         add-local-patch-support.patch
BuildRequires:  %{python_module GitPython}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module fasteners}
BuildRequires:  %{python_module lazy}
BuildRequires:  %{python_module pako}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       patch
Requires:       python-GitPython
Requires:       python-PyYAML
Requires:       python-fasteners
Requires:       python-lazy
Requires:       python-pako
Requires:       python-requests
Requires:       python-setuptools
Requires:       python-typing
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
msm is Mycroft Skills Manager, a command line tool to install/list/remove
Mycroft skills.

%prep
%autosetup -p1 -n mycroft-skills-manager-%{version}

sed -i -e "s/install_requires=\['GitPython', 'typing'/install_requires=['GitPython'/" setup.py
sed -i -e "s/data_files=\[('msm', \['LICENSE'\])\]//" setup.py
chmod -x LICENSE

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/msm
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_mycroft_skills_manager.py and test_skill_repo.py clone a git repo from GitHub already in their __init__
# test_main.py also clones a repo in init via self.base_params
# run_pip calls pip to install some dependencies
%pytest --ignore tests/test_mycroft_skills_manager.py --ignore tests/test_skill_repo.py --ignore tests/test_main.py -k "not run_pip" tests

%post
%python_install_alternative msm

%postun
%python_uninstall_alternative msm

%files %{python_files}
%license LICENSE
%python_alternative %{_bindir}/msm
%{python_sitelib}/msm
%{python_sitelib}/msm-%{version}-py%{python_version}.egg-info

%changelog
* Thu May 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprecated
  %%patchN syntax.
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Jan 22 2020 Martin Sirringhaus <martin.sirringhaus@suse.com>
- Updating to 0.8.5:
  * Fix raising of errors when install and remove fails.
- Updating to 0.8.4:
  * Add method to manually clear cache.
  * Limit supported python versions to 3.5+
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.8.3:
  * Switches default branch to 19.08
* Tue Aug 27 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.8.2
  * Add new platforms
  * Remove temporary copy of skill after action
  * added a skill_list property to cache the results of the list() method
  * added tests for more coverage
  * Fix infinite recursion issue
  * Make from_folder use msm skill cache if possible
- reapplied add-local-patch-support.patch
* Wed Jul 24 2019 pgajdos@suse.com
- version update to 0.7.8
  * Allow limiting the number of threads when running the apply() method.
  * Fix Skill GID for skills not in marketplace
  * Make sure skills.json file is updated from changes to skill GID
  * Cache marketplace skills meta data
* Fri May 24 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.7.6
  * Handle connection error when fetching skills meta data
  * Fix is_dirty when path is missing.
  * Fix skill name when using from_folder
  * Fix curate skills list
  * Dirty property to check if skill is modified
  * Return empty dict instead of None from get_skill_entry
  * Use in-place dict creation
  * Define skills_data_hash in __init__
  * Update hash after saving file
  * Raise instead of ignoring non-revertable errors
  * Fix python dependency installation
  * Add lazy as requirement in setup.py
  * Add pyyaml to setup.py
- take upstream tarball to launch at least some tests
- removed patch fix-skills-directories.patch
  * apparently incorrect, it was breaking tests
* Sat Feb  9 2019 Antonio Larrosa <alarrosa@suse.com>
- Fix removal of typing dependency so it's correctly removed
- Add Requires python-fasteners
* Sat Feb  2 2019 alarrosa@suse.com
- Update to python-msm 0.6.3
  * Do not destroy the existing repo on git errors
- Update to python-msm 0.6.2
  * Convert booleans in installed field to 0
- Update to python-msm 0.6.1
  * Make sure saving_handled is reset
  * Handle writing automatically
- Update to python-msm 0.6.0
  * Use existing installation/update times
  * Only write skills data if the info has changed
  * Fix update_deps() issue with constraints
  * Fix handling of beta and cleanup
  * Add process lock using fasteners
  * Add handling of the skills.json file
  * Updates returns True if an update occured
  * Try to handle errors in the .skills-repo
  * Add option to use pip constraints
- Rebase patches:
  * add-local-patch-support.patch
  * do-not-run-pip-or-requirements-script.patch
  * fix-skills-directories.patch
* Thu Nov  1 2018 alarrosa@suse.com
- Update to python-msm 0.5.19
  * Add optional skill and author args to update
  * Add LICENSE to package
  * Normalize license headers
  * Change default branch to 18.08
  * Remove python2 support
- Rebase add-local-patch-support.patch and fix-skills-directories.patch
* Mon Aug 27 2018 alarrosa@suse.com
- Fix the sed like that removes the typing dependency which is not needed
  in python 3.5+ .
* Sun Aug 26 2018 alarrosa@suse.com
- Update to python-msm 0.5.18
  * Handle the new default skill listings
- Drop fix-dependencies.patch and replace it with a sed call since
  otherwise we have to rebase it for every release.
* Sat Aug 11 2018 alarrosa@suse.com
- Add do-not-run-pip-or-requirements-script.patch to make msm not run pip
  or the requirements script when installing a skill. pip is not used
  by the rest of the mycroft packages and then running scripts from the
  web isn't nice security-wise.
- Add add-local-patch-support.patch to be able to fix issues with skills
  when they're installed.
* Mon Jul 30 2018 tchvatal@suse.com
- Install license file
* Sat Jul 28 2018 alarrosa@suse.com
- Add fix-dependencies.patch to remove the typing dependency which
  is not needed in python3
- Add json_helper.py into fix-skills-directories.patch
* Sat Jul 28 2018 alarrosa@suse.com
- Update to python-msm 0.5.17
  * Make submodule parsing fail gracefully
* Sun Jul  1 2018 alarrosa@suse.com
- Update to python-msm 0.5.16
  * Expose extract_author
- Update to python-msm 0.5.15
  * Fix git asking for a password during update
- Update to python-msm 0.5.14
  * License as Apache 2.0
  * Code formatting changes
* Sun Jun  3 2018 alarrosa@suse.com
- Initial release of python-msm 0.5.13
- Add fix-skills-directories.patch
